@@ -21,7 +21,7 @@ sub DESCRIPTION {
 
 # Regexp compiled from dh_nodejs/dh_files.excluded
 my $fileIgnored =
-qr/^(?:c(?:o(?:ntribute|pying)|hange(?:log|s?))|.*\.(?:m(?:arkdown|d)|pdf|txt)|r(?:ollup\.config\.js|eadme)|t(?:sconfig\.json|ests?\.js)|aut(?:otest\.watchr|hors?)|(?:package-|yarn\.)lock|g(?:runt|ulp)file\.js|(?:license|\.).*|bower\.json|makefile|history)$/i;
+qr/^(?:a(?:ut(?:otest\.watchr|hors?)|ppveyor\.yml)|c(?:o(?:ntribute|pying)|hange(?:log|s?))|.*\.(?:m(?:arkdown|d)|pdf|txt)|r(?:ollup\.config\.js|eadme)|t(?:sconfig\.json|ests?\.js)|(?:package-|yarn\.)lock|g(?:runt|ulp)file\.js|(?:license|\.).*|bower\.json|makefile|history)$/i;
 
 # Regexp compiled from dh_nodejs/dh_dirs.excluded
 my $dirIgnored = qr{^(?:(?:example|test|doc)s?|node_modules|\..*)(?:/.*)?}i;
@@ -86,6 +86,39 @@ sub component_list {
     return \%packages;
 }
 
+sub pattern {
+    my ( $self, $line ) = @_;
+    my ( $p, $pattern );
+    print "Parsing expression $line\n";
+    $line =~ m/^(.*?)(\*.*)$/ or die "Bad line $line";
+    my $tmp = $line;
+    my ( $dir, $expr ) = ( $1, $2 );
+    if ($dir) {
+        $dir =~ s#/+$##;
+        $p = $dir;
+    }
+    else {
+        $p = '.';
+    }
+    my @dirs = ( "$p/", split( m#\*\*/#, $expr ) );
+    $expr =~ s#.*\*\*/##;
+    pop @dirs if ($expr);
+    $expr = quotemeta($expr);
+    $expr =~ s#\\\*#[^/]*#g;
+    my $pat = '^' . join( '.*(?<=/)', @dirs ) . $expr . '$';
+    print "Line $tmp becomes: $pat\n";
+    eval { $pattern = qr/$pat/ };
+    die << "EOF" if ($@);
+
+Unable to parse expression: "$tmp" (converted into "$pat")
+If it is correct, please fill a bug against pkg-js-tools.
+To workaround, you can overwrite "files" field in debian/nodejs. See
+/usr/share/doc/pkg-js-tools/README.md.
+
+EOF
+    return ( $p, $pattern );
+}
+
 # Private method to install modules: search for package.json#files field, if
 # not found, install any files except ignored by regexp
 sub install_module {
@@ -155,32 +188,8 @@ sub install_module {
     my @dest;
     foreach my $p (@files) {
         my $pattern;
-        if ( $p =~ m/^(.*?)(\*.*)$/ ) {
-            my $tmp = $p;
-            print "Parsing expression $p\n";
-            my ( $dir, $expr ) = ( $1, $2 );
-            if ($dir) {
-                $dir =~ s#/+$##;
-                $p = $dir;
-            }
-            else {
-                $p = '.';
-            }
-            my @dirs = ( "$p/", split( /\*\*/, $expr ) );
-            $expr =~ s/.*\*\*//;
-            pop @dirs if ($expr);
-            $expr = quotemeta($expr);
-            $expr =~ s#\\\*#[^/]*#g;
-            my $pat = '^' . join( '.*', @dirs ) . $expr . '$';
-            eval { $pattern = qr/$pat/ };
-            die << "EOF" if ($@);
-
-Unable to parse expression: "$tmp" (converted into "$pat")
-If it is correct, please fill a bug against pkg-js-tools.
-To workaround, you can overwrite "files" field in debian/nodejs. See
-/usr/share/doc/pkg-js-tools/README.md.
-
-EOF
+        if ( $p =~ m/\*/ ) {
+            ( $p, $pattern ) = $self->pattern($p);
         }
         find(
             sub {
